####################################################################
# DISPL.-BASED FIBER ELEMENTS, REINFORCED-CONCRETE, REF: 'RCFRAME' #
####################################################################
#
#
#    _________________________   _
#   |            |            |  
#   |            |            | 12'
#   |            |            |
#   |____________|____________|  _
#   |            |            |
#   |            |            |
#   |            |            | 15'
#   |            |            |
#   |            |            |  _
#  ===          ===          ===
#   |     24'    |     24'    |
#
#
set load 225.0
#
#
#
# comment out one of lines
#set displayMode "displayON"
set displayMode "displayOFF"

# CREATE THE MODEL BUILDERS
model BasicBuilder -ndm 2 -ndf 3
# reliability

# DEFINE NODES
#    tag  X   Y
node  1   0   0
node  2   0 180
node  3   0 324
node  4 288   0
node  5 288 180
node  6 288 324
node  7 576   0
node  8 576 180
node  9 576 324

# SINGLE POINT CONSTRAINTS
#   node DX DY RZ
fix   1   1  1  1
fix   4   1  1  1
fix   7   1  1  1

# DEFINE MATERIALS
# Cover concrete
#                          tag  -f'c     -epsco    -f'cu  -epscu
uniaxialMaterial Concrete01 1   -$Fc1RV  -0.002    0.0    -0.006
# Core concrete
uniaxialMaterial Concrete01 2   -$Fc2RV  -0.005    -4.70  -0.02

# Steel model
#                        tag fy    E     b 
uniaxialMaterial Steel01  3  $FyRV 30000 0.02    

# DEFINE SECTIONS
# Interior column section
section fiberSec 1 {
   #           mat nfIJ nfJK   yI  zI    yJ  zJ    yK  zK    yL  zL
   patch quadr  2    1   12 -11.5  10 -11.5 -10  11.5 -10  11.5  10
   patch quadr  1    1   14 -13.5 -10 -13.5 -12  13.5 -12  13.5 -10
   patch quadr  1    1   14 -13.5  12 -13.5  10  13.5  10  13.5  12
   patch quadr  1    1    2 -13.5  10 -13.5 -10 -11.5 -10 -11.5  10
   patch quadr  1    1    2  11.5  10  11.5 -10  13.5 -10  13.5  10

   #              mat nBars area    yI zI    yF zF
   layer straight  3    6   1.56 -10.5  9 -10.5 -9
   layer straight  3    6   1.56  10.5  9  10.5 -9
}

# Exterior column section
section fiberSec 2 {
   patch quadr 2 1 10 -10  10 -10 -10  10 -10  10  10
   patch quadr 1 1 12 -12 -10 -12 -12  12 -12  12 -10
   patch quadr 1 1 12 -12  12 -12  10  12  10  12  12
   patch quadr 1 1  2 -12  10 -12 -10 -10 -10 -10  10
   patch quadr 1 1  2  10  10  10 -10  12 -10  12  10
   layer straight 3 6 0.79 -9 9 -9 -9
   layer straight 3 6 0.79  9 9  9 -9
}

# Girder section
section fiberSec 3 {
   patch quadr 1 1 12 -12 9 -12 -9 12 -9 12 9
   layer straight 3 4 1.00 -9 9 -9 -9
   layer straight 3 4 1.00  9 9  9 -9
}

# NUMBER OF INTEGRATION POINTS
set nP 4

# GEOMETRIC TRANSFORMATION
geomTransf Linear 1

# DEFINE DISPLACEMENT BEAM-COLUMN ELEMENTS                
# Columns
#                      tag ndI ndJ  nPts secID transf
element dispBeamColumn  1   1   2    $nP   2      1
element dispBeamColumn  2   2   3    $nP   2      1
element dispBeamColumn  3   4   5    $nP   1      1
element dispBeamColumn  4   5   6    $nP   1      1
element dispBeamColumn  5   7   8    $nP   2      1
element dispBeamColumn  6   8   9    $nP   2      1

# Beams
element dispBeamColumn  7   2   5    $nP   3      1
element dispBeamColumn  8   5   8    $nP   3      1
element dispBeamColumn  9   3   6    $nP   3      1
element dispBeamColumn 10   6   9    $nP   3      1

# CONSTANT GRAVITY LOADS
pattern Plain 1 Linear {
   #    node  FX    FY   MZ
   load   2  0.0 -192.0 0.0 
   load   5  0.0 -384.0 0.0
   load   8  0.0 -192.0 0.0
   load   3  0.0  -96.0 0.0
   load   6  0.0 -192.0 0.0
   load   9  0.0  -96.0 0.0
}
pattern Plain 2 Linear {
   #    node  FX   FY   MZ
   load   2 $load  0.0  0.0
   load   3 $load  0.0  0.0
}

# FINITE ELEMENT ANALYSIS MODEL
integrator LoadControl  1   3  1  1
test NormDispIncr  1.0e-06     10         0
algorithm Newton
numberer RCM
constraints Transformation
#system SparseGeneral -piv
system ProfileSPD
#sensitivityIntegrator -static
#sensitivityAlgorithm -computeAtEachStep 
analysis Static

# RECORDERS
recorder Node -file Drift.txt -time -node 3 -dof 1 disp


######################################################################
# THIS IS AN AUXILIARY FILE FOR THE STATIC RC-FRAME EXAMPLES,        #
# IT SIMPLY CONTAINS THE COMMANDS THAT SHOULD BE EXECUTED FOR EACH   #
# LIMIT-STATE FUNCTION EVALUATION.                                   #
######################################################################

integrator LoadControl  0.05   3   0.05    0.05
analyze 16

integrator LoadControl  0.02   3   0.02    0.02
analyze 10

#puts $FyRV


